@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "4.1.51133"
+IAddressBook_VERSION = "4.1.51204"
 
 class IAddressBook(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -331,6 +331,20 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+    def multipleGetById (self, ids ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
