@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ICalendar_VERSION = "4.1.51133"
+ICalendar_VERSION = "4.1.51204"
 
 class ICalendar(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -292,6 +292,20 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VEventSeriesSerDer__()), response)
+    def multipleGetById (self, ids ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
