@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ITodoList_VERSION = "4.1.51133"
+ITodoList_VERSION = "4.1.51204"
 
 class ITodoList(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -303,6 +303,20 @@ class ITodoList(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
+    def multipleGetById (self, ids ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = __encoded__);
+        from netbluemind.todolist.api.VTodo import VTodo
+        from netbluemind.todolist.api.VTodo import __VTodoSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
     def containerChangelog (self, arg0 ):
         postUri = "/_changelog";
         __data__ = None
